@@ -318,7 +318,13 @@ class Decoder {
 			PyObject* tmp = NULL;
 
 			if (parseDate && __read_date(cursor, cursorOut, &tmp)) {
-				return tmp;
+				// when parsed invalid date like string, eg: 8922-00-01
+				// just continue string parsing
+				if (tmp == NULL && PyErr_Occurred()) {
+					PyErr_Clear();
+				} else {
+					return tmp;
+				}
 			}
 
 			if (sizeof(CHIN) == 1) {
@@ -425,15 +431,16 @@ class Decoder {
 			static inline bool ReadFraction(CHIN* cursor, CHIN** cursorOut, int* result) {
 				if (*(cursor++) == '.') {
 					CHIN* start = cursor;
+					int factor = 100000;
 					if (Decoder_IsNumber(*cursor)) {
 						do {
-							*result = *result * 10 + (*(cursor++) - '0');
-						} while (Decoder_IsNumber(*cursor) && cursor - start < 6);
-
-						// eat all remaining numbers
-						while (Decoder_IsNumber(*cursor)) {
+							if (factor > 0) {
+								*result = *result + (*(cursor) - '0') * factor;
+								factor = factor / 10;
+							}
 							++cursor;
-						};
+						} while (Decoder_IsNumber(*cursor));
+
 						*cursorOut = cursor;
 						return true;
 					}
@@ -932,6 +939,8 @@ class Decoder {
 						break;
 					}
 				} else {
+					key = NULL;
+					value = NULL;
 					Decoder_DictError("\"");
 					break;
 				}
